annoByCpG: Annotate the vector integrated site by CpG islands.

Description Usage Arguments Value

View source: R/annoByCpG.R

Description

After load CpG island informaton from a ucsc data file, this function shows CpG island information related with vector integrated sites. User can get query sequence inserted in CpG site and distribution graph by this function.

Usage

1
annoByCpG(hits, randomSet = NULL, mapTool = 'blast', organism = 'hg19', interval = 5000, range = c(-20000, 20000),

Arguments

hits

a GR object. This object made from *makeInputs* function.

randomSet

a string vector. Type path to load a random set. If this value is null, random distribution analysis is not executed.

mapTool

a character. Function serve two types of file such as outputs from BLAST and BLAT. Default is 'blast'. If you want to use BLAT output, use 'blat'.

organism

a single character. This function serves 3 versions of organisms such as hg19, hg38 (Human) and galGal6 (Chicken). Default is 'hg19'.

interval

an integer vector. This number means interval number for distribution analysis. Default is 5000.

range

an integer array. It means the range for highlight region of this analysis. Default range is c(-20000, 20000).

outpath

an string vector. Plots are saved in this path. Default value is R home directory.

cpglen

an integer vector. Validate length of CpG sites in islands.

dbPath

a string vector. Directory path of database files.

Value

Return a result list constituted by insertion table, distribution table and a GenomicRange object of CpG data.


bioinfo16/IRFinder documentation built on Aug. 19, 2019, 10:37 a.m.